package consume

import (
	"os"
	"query-service/internal/drivers/brokerdriver"
	"query-service/internal/usecases/convertquery"
	"query-service/internal/usecases/produce"
	"query-service/internal/usecases/request"
)

// Service wraps consumer methods
// broker is Alice broker created in brockerdriver driver
type Service struct {
	broker         brokerdriver.Broker
	producer       produce.UseCase
	queryConverter convertquery.UseCase
	requestSender  request.UseCase
}

// NewService creates a new service
func NewService(broker brokerdriver.Broker, produceService produce.UseCase, converQueryService convertquery.UseCase, requestSenderService request.UseCase) *Service {
	return &Service{
		broker:         broker,
		producer:       produceService,
		queryConverter: converQueryService,
		requestSender:  requestSenderService,
	}
}

var podName string

// Start starts consuming
func (s *Service) Start() {

	podName = os.Getenv("POD_NAME")

	// Create consumer
	consumer := s.broker.CreateConsumer()

	consumer.SetMessageHandler(s.HandleMessage)

	// Start consuming messages
	consumer.ConsumeMessages()
}
