package convertquery

// Service is a model for the convertquery use case
type Service struct {
}

// NewService creates a new convertquery service
func NewService() *Service {
	return &Service{}
}

// Constraint datatypes
// text		  MatchTypes: exact/contains/startswith/endswith
// number   MatchTypes: GT/LT/EQ
// bool     MatchTypes: EQ/NEQ

// Ranges dus tussen 10 half 5 bijv.

// Struct used for JSON conversion of the incoming byte array
type parsedJSON struct {
	Return    returnStruct     //`json:"return"`
	Entities  []entityStruct   //`json:"entities"`
	Relations []relationStruct //`json:"relations"`
}

// returnStruct holds the indices of the entities and relations that need to be returned
type returnStruct struct {
	Entities  []int //`json:"entities"`
	Relations []int //`json:"relation"`
}

// entityStruct encapsulates a single entity with its corresponding constraints
type entityStruct struct {
	Type        string             //`json:"type"`
	Constraints []constraintStruct //`json:"constraints"`
}

// relationStruct encapsulates a single relation with its corresponding constraints
type relationStruct struct {
	Type        string //`json:"type"`
	EntityFrom  int
	EntityTo    int
	Depth       searchDepthStruct
	Constraints []constraintStruct
}

// searchDepthStruct holds the range of traversals for the relation
type searchDepthStruct struct {
	Min int
	Max int
}

// constraintStruct holds the information of the constraint
type constraintStruct struct {
	Attribute string //`json:"attribute"`
	Value     string //`json:"value"`
	DataType  string //`json:"dataType"`
	MatchType string //`json:"matchType"`
}
